# pyCoastal

A Python module for Coastal Engineering calculations.

Copyright (c) 2025 Stefano Biondi
Licensed under the MIT License. See LICENSE file for details.

# Installation
# Clone the repository and navigate to the main folder
```bash
git clone https://github.com/stebiondi/pyCoastal.git
cd pyCoastal
```

# Install build tools
```bash
pip install --upgrade pip setuptools wheel build
```

# Build your package (creates dist/ folder)
```bash
python -m build
```

# Install pyCoastal in editable (dev) mode
```bash
pip install -e 
```

# Install via pip:

```bash
pip install pyCoastal
```
